@@ -63,8 +63,8 @@ class DeviceSchema(schema.Schema):
     test_image_prompts = schema.ListOption(default=["\(initramfs\)",
                                                     "linaro-test",
                                                     "/ #",
+                                                    "root@linaro#",
                                                     "root@android",
-                                                    "root@linaro",
                                                     "root@master",
                                                     "root@linaro-nano:~#",
                                                     "root@linaro-developer:~#",
@@ -270,6 +270,8 @@ class DeviceSchema(schema.Schema):
     fastboot_efi_image = schema.StringOption(default=None)
     run_boot_cmds = schema.BoolOption(default=False)
     boot_fat_image_only = schema.BoolOption(default=False)
+    mkbootimg_binary = schema.StringOption(default=None)
+    dtbtool_binary = schema.StringOption(default=None)
     rootfs_partition = schema.StringOption(default='userdata')
     start_fastboot_command = schema.StringOption(default=None)
     shared_working_directory = schema.StringOption(default=None)
@@ -308,6 +310,12 @@ class DeviceSchema(schema.Schema):
     vexpress_requires_trusted_firmware = schema.BoolOption(default=False)
     bridged_networking = schema.BoolOption(default=False)
     bridge_interface = schema.StringOption(default="br0")
+    vexpress_firmware_path_hwpack = schema.StringOption(default=None)
+    vexpress_firmware_path_android = schema.StringOption(default=None)
+    vexpress_complete_firmware = schema.BoolOption(default=False)
+    vexpress_firmware_default = schema.StringOption(default=None)
+    vexpress_flash_range_low = schema.StringOption(default=None)
+    vexpress_flash_range_high = schema.StringOption(default=None)
 
 
 class OptionDescriptor(object):
