@@ -64,14 +64,14 @@ class IpmiPxeTarget(Target):
 
     def power_on(self):
         self.bootcontrol.power_on_boot_image()
-        self._auto_login(self.proc)
+        self._monitor_boot(self.proc, self.tester_ps1, self.tester_ps1_pattern)
         return self.proc
 
     def power_off(self, proc):
         self.bootcontrol.power_off()
         finalize_process(self.proc)
 
-    def deploy_linaro(self, hwpack, rfs, dtb, rootfstype, bootloadertype):
+    def deploy_linaro(self, hwpack, rfs, dtb, rootfstype, bootloadertype, qemu_pflash=None):
         image_file = generate_image(self, hwpack, rfs, dtb, self.scratch_dir,
                                     bootloadertype, rootfstype,
                                     extra_boot_args='1', image_size='1G')
@@ -79,7 +79,7 @@ class IpmiPxeTarget(Target):
         self._deploy_image(image_file, '/dev/%s'
                            % self.config.sata_block_device)
 
-    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootloadertype):
+    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootloadertype, qemu_pflash=None):
         image_file = download_image(image, self.context, self.scratch_dir)
         self.customize_image(image_file)
         self._deploy_image(image_file, '/dev/%s'
@@ -183,12 +183,7 @@ class IpmiPxeTarget(Target):
         self._enter_bootloader(self.proc)
         boot_cmds = self._load_boot_cmds(default='boot_cmds_master')
         self._customize_bootloader(self.proc, boot_cmds)
-        self.proc.expect(self.config.image_boot_msg,
-                         timeout=self.config.image_boot_msg_timeout)
-        self._wait_for_prompt(self.proc, self.config.test_image_prompts,
-                              self.config.boot_linaro_timeout)
-        self.proc.sendline('export PS1="%s"' % self.MASTER_PS1)
-        self.proc.expect(self.MASTER_PS1_PATTERN, timeout=180, lava_no_logging=1)
+        self._monitor_boot(self.proc, self.MASTER_PS1, self.MASTER_PS1_PATTERN)
         runner = MasterCommandRunner(self)
         logging.info("System is in master image now")
 
