@@ -32,10 +32,12 @@ from lava_dispatcher.utils import (
     connect_to_serial,
     extract_rootfs,
     extract_ramdisk,
-    extract_modules,
+    extract_overlay,
     create_ramdisk
 )
 
+import pexpect
+
 
 class BaseDriver(object):
 
@@ -45,9 +47,9 @@ class BaseDriver(object):
         self.config = device.config
         self._default_boot_cmds = 'boot_cmds_ramdisk'
 
-    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, modules, rootfs, nfsrootfs,
+    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
                              bootloader, firmware, bl1, bl2, bl31, rootfstype,
-                             bootloadertype, target_type, scratch_dir):
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         """
         """
         raise NotImplementedError("deploy_linaro_kernel")
@@ -69,9 +71,9 @@ class stmc(BaseDriver):
         self._boot_tags = {}
         self._booted = False
 
-    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, modules, rootfs, nfsrootfs,
+    def deploy_linaro_kernel(self, kernel, ramdisk, dtb, overlays, rootfs, nfsrootfs,
                              bootloader, firmware, bl1, bl2, bl31, rootfstype,
-                             bootloadertype, target_type, scratch_dir):
+                             bootloadertype, target_type, scratch_dir, qemu_pflash=None):
         kernel_url = kernel
         dtb_url = dtb
         # At a minimum we must have a kernel
@@ -92,13 +94,14 @@ class stmc(BaseDriver):
             ramdisk = download_image(ramdisk, self.context,
                                      scratch_dir,
                                      decompress=False)
-            if modules is not None:
-                modules = download_image(modules, self.context,
-                                         scratch_dir,
-                                         decompress=False)
+            if overlays is not None:
                 ramdisk_dir = extract_ramdisk(ramdisk, scratch_dir,
                                               is_uboot=False)
-                extract_modules(modules, ramdisk_dir)
+                for overlay in overlays:
+                    overlay = download_image(overlay, self.context,
+                                             scratch_dir,
+                                             decompress=False)
+                    extract_overlay(overlay, ramdisk_dir)
                 ramdisk = create_ramdisk(ramdisk_dir, scratch_dir)
             stmc_command = ' '.join([stmc_command,
                                     self.config.jtag_stmc_ramdisk_command.format(RAMDISK=ramdisk)])
@@ -118,11 +121,12 @@ class stmc(BaseDriver):
             extract_rootfs(nfsrootfs, lava_nfsrootfs)
             self._boot_tags['{NFSROOTFS}'] = lava_nfsrootfs
             self._default_boot_cmds = 'boot_cmds_nfs'
-            if modules is not None and ramdisk is None:
-                modules = download_image(modules, self.context,
-                                         scratch_dir,
-                                         decompress=False)
-                extract_modules(modules, lava_nfsrootfs)
+            if overlays is not None and ramdisk is None:
+                for overlay in overlays:
+                    overlay = download_image(overlay, self.context,
+                                             scratch_dir,
+                                             decompress=False)
+                extract_overlay(overlay, lava_nfsrootfs)
 
         # Add suffix for boot commands
         self._stmc_command = stmc_command + ' --'
@@ -165,19 +169,37 @@ class stmc(BaseDriver):
 
     def connect(self, boot_cmds):
         if self.context.test_data.metadata.get('is_slave', 'false') == 'true':
-            # Wait for the STMC2 to be ready
-            self.context.transport.request_wait('lava_ms_ready')
+            # When booting in master-slave, the protocol is:
+            # 1/ self  : reboot the STMC2
+            # 2/ master: wait for the STMC2 prompt
+            # 3/ self  : reboot the board
+            # 4/ master: setup the serial relay
+            # 5/ self  : connect to the serial
+            # 6/ master: boot the board
+
+            # Reboot the STMC2 when the master is ready
+            self.context.transport.request_wait('lava_ms_reboot_STMC2')
+            logging.info("Hard resetting STMC2")
+            if not self.config.jtag_hard_reset_command:
+                raise CriticalError("'jtag_hard_reset_command' is required")
+            self.context.run_command(self.config.jtag_hard_reset_command)
+            self.context.transport.request_send('lava_ms_reboot_STMC2_done', None)
+
+            self.context.transport.request_wait('lava_ms_reboot_board')
+            logging.info("Hard resetting platform")
+            if not self.config.hard_reset_command:
+                raise CriticalError("'hard_reset_command' is required")
+            self.context.run_command(self.config.hard_reset_command)
+            self.context.transport.request_send('lava_ms_reboot_board_done', None)
 
             # Connect to the STMC serial relay
+            self.context.transport.request_wait('lava_ms_ready')
             logging.info("Connecting to STMC serial relay")
             proc = connect_to_serial(self.context)
 
             # Ask the master to deliver the image
             self.context.transport.request_send('lava_ms_boot', None)
 
-            proc.expect(self.config.image_boot_msg,
-                        timeout=self.config.image_boot_msg_timeout)
-            return proc
         else:
             boot_cmds.insert(0, self._stmc_command)
             jtag_command = ' '.join(boot_cmds)
@@ -224,8 +246,17 @@ class stmc(BaseDriver):
 
             # Deliver images with STMC
             logging.info("Delivering images with STMC")
-            self.context.run_command(jtag_command, failok=False)
+            # Boot the board with a timeout on this command that MUST finish on
+            # time (the command block when failing to boot)
+            boot_proc = self.context.spawn(jtag_command, timeout=240)
+            try:
+                boot_proc.expect(pexpect.EOF)
+            except pexpect.TIMEOUT:
+                raise CriticalError("GDB is unable to boot the board")
 
-            proc.expect(self.config.image_boot_msg,
-                        timeout=self.config.image_boot_msg_timeout)
-            return proc
+            logging.info("GDB has finished, waiting for the board prompt")
+
+        # Wait for the prompt
+        proc.expect(self.config.image_boot_msg,
+                    timeout=self.config.image_boot_msg_timeout)
+        return proc
