@@ -93,15 +93,16 @@ class SDMuxTarget(Target):
 
         self.proc = connect_to_serial(self.context)
 
-    def deploy_linaro(self, hwpack, rootfs, dtb, bootloadertype, rootfstype):
+    def deploy_linaro(self, hwpack, rootfs, dtb, bootloadertype, rootfstype, qemu_pflash=None):
         img = generate_image(self, hwpack, rootfs, dtb, self.scratch_dir,
                              rootfstype, bootloadertype)
         self.customize_image(img)
         self._write_image(img)
 
-    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootloadertype):
+    def deploy_linaro_prebuilt(self, image, dtb, rootfstype, bootloadertype, qemu_pflash=None):
         img = download_image(image, self.context)
         self.customize_image(img)
+
         self._write_image(img)
 
     def _customize_android(self, img):
@@ -113,12 +114,21 @@ class SDMuxTarget(Target):
                 f.write('\n# LAVA CUSTOMIZATIONS\n')
                 f.write('PS1="%s"\n' % self.tester_ps1)
 
-    def deploy_android(self, boot, system, data, rootfstype, bootloadertype,
+    def deploy_android(self, images, rootfstype, bootloadertype,
                        target_type):
         scratch = self.scratch_dir
-        boot = download_image(boot, self.context, scratch, decompress=False)
-        data = download_image(data, self.context, scratch, decompress=False)
-        system = download_image(system, self.context, scratch, decompress=False)
+
+        for image in images:
+            if image['partition'] == 'boot':
+                boot = download_image(image['url'], self.context, scratch, decompress=False)
+            elif image['parition'] == 'system':
+                system = download_image(image['url'], self.context, scratch, decompress=False)
+            elif image['partition'] == 'userdata':
+                data = download_image(image['url'], self.context, scratch, decompress=False)
+            else:
+                msg = 'Unsupported partition option: %s' % image['partition']
+                logging.warning(msg)
+                raise CriticalError(msg)
 
         img = os.path.join(scratch, 'android.img')
         device_type = self.config.lmc_dev_arg
@@ -144,11 +154,7 @@ class SDMuxTarget(Target):
         self._enter_bootloader(self.proc)
         boot_cmds = self._load_boot_cmds()
         self._customize_bootloader(self.proc, boot_cmds)
-        self._auto_login(self.proc)
-        self._wait_for_prompt(self.proc, self.config.test_image_prompts,
-                              self.config.boot_linaro_timeout)
-        self.proc.sendline('export PS1="%s"' % self.tester_ps1,
-                           send_char=self.config.send_char)
+        self._monitor_boot(self.proc, self.tester_ps1, self.tester_ps1_pattern)
 
     def mux_device(self):
         """
