@@ -309,6 +309,25 @@ class Target(object):
                         return dest
         return dest
 
+    def _find_file(self, rootdir, pattern):
+        dest = None
+        for root, dirs, files in os.walk(rootdir, topdown=False):
+            for file_name in files:
+                if re.match(pattern, file_name):
+                    logging.debug("Found a match: %s" % file_name)
+                    dest = os.path.join(root, file_name)
+                    return dest
+        return dest
+
+    def _find_dir(self, rootdir, pattern):
+        dest = None
+        for root, dirs, files in os.walk(rootdir, topdown=False):
+            for dir_name in dirs:
+                if re.match(pattern, dir_name):
+                    dest = os.path.join(root, dir_name)
+                    return dest
+        return dest
+
     def _wait_for_prompt(self, connection, prompt_pattern, timeout):
         wait_for_prompt(connection, prompt_pattern, timeout)
 
@@ -583,13 +602,8 @@ class Target(object):
                                                   good)
                 start = time.time()
             except pexpect.TIMEOUT:
-                # Get the last line from the pexpect buffer
-                last_kmsg = connection.before.rstrip().split('\r\n')[-1]
-                msg = "Kernel Error:  %s " % last_kmsg
-                logging.error(msg)
-                kernel_boot_time = 0.0
                 self.context.test_data.add_result(wait_for_kernel_boot,
-                                                  bad, message=msg)
+                                                  bad)
                 raise
 
         try:
@@ -855,10 +869,12 @@ class Target(object):
             # substitution.
             profile_path = profile_path % rootdir
 
-        with open(profile_path, 'a') as f:
-            f.write('export PS1="%s"\n' % self.tester_ps1)
-        with open('%s/etc/hostname' % rootdir, 'w') as f:
-            f.write('%s\n' % self.config.hostname)
+        if os.path.exists(profile_path):
+            with open(profile_path, 'a') as f:
+                f.write('export PS1="%s"\n' % self.tester_ps1)
+        if os.path.exists('%s/etc/hostname' % rootdir):
+            with open('%s/etc/hostname' % rootdir, 'w') as f:
+                f.write('%s\n' % self.config.hostname)
 
     @property
     def target_distro(self):
