@@ -277,6 +277,8 @@ class LavaTestJob(object):
             return None
 
     def run(self, transport=None, group_data=None, vm_host_ip=None):
+        if group_data:
+            logging.debug("Group initialisation: %s" % json.dumps(group_data))
         self.context.assign_transport(transport)
         self.context.assign_group_data(group_data)
         validate_job_data(self.job_data)
@@ -482,7 +484,7 @@ class LavaTestJob(object):
                             (cmd['command']))
                         err_msg = ""
                     self.context.test_data.add_result(
-                        action.test_name(**params), status, err_msg)
+                        action.test_name(**params), status, message=err_msg)
         except:
             # Capture all user-defined and non-user-defined critical errors
             self.context.test_data.job_status = 'fail'
