@@ -18,9 +18,20 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from lava_dispatcher.pipeline import Action
+from lava_dispatcher.pipeline.action import Action
 
 
 class SubmitResultsAction(Action):
 
     name = 'submit_results'
+
+    def validate(self):
+        super(SubmitResultsAction, self).validate()
+        if 'repeat' in self.parameters:
+            self.errors = "%s does not support repeat" % self.name
+
+    def run(self, connection, args=None):
+        return connection
+
+    def cleanup(self):
+        pass
