@@ -71,18 +71,18 @@ class TestShellAction(TestAction):
         self.match = SignalMatch()
 
     def validate(self):
-        if 'test_image_prompts' not in self.job.device:
+        if "test_image_prompts" not in self.job.device:
             self.errors = "Unable to identify test image prompts from device configuration."
-        if 'definitions' in self.parameters:
-            for testdef in self.parameters['definitions']:
-                if 'repository' not in testdef:
+        if "definitions" in self.parameters:
+            for testdef in self.parameters["definitions"]:
+                if "repository" not in testdef:
                     self.errors = "Repository missing from test definition"
         # Extend the list of patterns when creating subclasses.
         self.patterns.update({
-            'exit': '<LAVA_TEST_RUNNER>: exiting',
-            'eof': pexpect.EOF,
-            'timeout': pexpect.TIMEOUT,
-            'signal': r'<LAVA_SIGNAL_(\S+) ([^>]+)>',
+            "exit": "<LAVA_TEST_RUNNER>: exiting",
+            "eof": pexpect.EOF,
+            "timeout": pexpect.TIMEOUT,
+            "signal": r"<LAVA_SIGNAL_(\S+) ([^>]+)>",
         })
         super(TestShellAction, self).validate()
 
@@ -91,12 +91,12 @@ class TestShellAction(TestAction):
         Common run function for subclasses which define custom patterns
         """
         # Sanity test: could be a missing deployment for some actions
-        if 'boot-result' not in self.data:
+        if "boot-result" not in self.data:
             raise RuntimeError("No boot action result found")
         connection = super(TestShellAction, self).run(connection, args)
-        if self.data['boot-result'] != 'success':
+        if self.data["boot-result"] != "success":
             self.logger.debug("Skipping test definitions - previous boot attempt was not successful.")
-            self.results.update({self.name: 'skipped'})
+            self.results.update({self.name: "skipped"})
             # FIXME: with predictable UID, could set each test definition metadata to "skipped"
             return connection
 
@@ -107,13 +107,11 @@ class TestShellAction(TestAction):
 
         self.logger.info("Executing test definitions using %s" % connection.name)
         self.logger.debug("Setting default test shell prompt")
-        connection.prompt_str = self.job.device['test_image_prompts']
+        connection.prompt_str = self.job.device["test_image_prompts"]
         self.logger.debug("Setting default timeout: %s" % self.timeout.duration)
         connection.timeout = self.timeout
         self.wait(connection)
 
-        self.match = SignalMatch()
-
         # FIXME: a predictable UID could be calculated from existing data here.
         # instead, uuid is read from the params to set _current_handler
         # FIXME: can only be run once per TestAction, so collate all patterns for all test definitions.
@@ -122,15 +120,15 @@ class TestShellAction(TestAction):
         # FIXME: not being set
         if self.signal_director.test_uuid:
             self.patterns.update({
-                'test_case': self.data['test'][self.signal_director.test_uuid]['testdef_pattern']['pattern'],
+                "test_case": self.data["test"][self.signal_director.test_uuid]["testdef_pattern"]["pattern"],
             })
 
         with connection.test_connection() as test_connection:
             # the structure of lava-test-runner means that there is just one TestAction and it must run all definitions
             test_connection.sendline(
                 "%s/bin/lava-test-runner %s" % (
-                    self.data['lava_test_results_dir'],
-                    self.data['lava_test_results_dir']),
+                    self.data["lava_test_results_dir"],
+                    self.data["lava_test_results_dir"]),
             )
 
             if self.timeout:
@@ -147,67 +145,69 @@ class TestShellAction(TestAction):
         Stores the results of testcases inside the TestAction
         Call from subclasses before checking subclass-specific events.
         """
-        if event == 'exit':
-            self.logger.info('ok: lava_test_shell seems to have completed')
-            return False
+        ret_val = False
+        if event == "exit":
+            self.logger.info("ok: lava_test_shell seems to have completed")
 
-        elif event == 'eof':
-            self.logger.warning('err: lava_test_shell connection dropped')
-            self.errors = 'lava_test_shell connection dropped'
-            return False
+        elif event == "eof":
+            self.logger.warning("err: lava_test_shell connection dropped")
+            self.errors = "lava_test_shell connection dropped"
 
-        elif event == 'timeout':
+        elif event == "timeout":
             # if target.is_booted():
             #    target.reset_boot()
-            self.logger.warning('err: lava_test_shell has timed out')
-            self.errors = 'lava_test_shell has timed out'
-            return False
+            self.logger.warning("err: lava_test_shell has timed out")
+            self.errors = "lava_test_shell has timed out"
 
-        elif event == 'signal':
+        elif event == "signal":
             name, params = test_connection.match.groups()
             self.logger.debug("Received signal: <%s> %s" % (name, params))
             params = params.split()
-            if name == 'STARTRUN':
+            if name == "STARTRUN":
                 self.signal_director.test_uuid = params[1]
             #    self._handle_testrun(params)
-            if name == 'TESTCASE':
+            elif name == "TESTCASE":
                 data = handle_testcase(params)
                 res = self.match.match(data)  # FIXME: rename!
-                self.logger.debug('result: %s' % res)
-                self.data['test'][self.signal_director.test_uuid].setdefault('results', OrderedDict())
+                self.logger.debug("result: %s" % res)
+
+                p_res = self.data["test"][
+                    self.signal_director.test_uuid
+                ].setdefault("results", OrderedDict())
 
                 # prevent losing data in the update
                 # FIXME: support parameters and retries
-                if res['test_case_id'] in self.data['test'][self.signal_director.test_uuid]['results']:
-                    raise JobError("Duplicate test_case_id in results: %s", res['test_case_id'])
+                if res["test_case_id"] in p_res:
+                    raise JobError("Duplicate test_case_id in results: %s", res["test_case_id"])
                 # turn the result dict inside out to get the unique test_case_id as key and result as value
                 self.results.update({
-                    res['test_case_id']: res['result']
+                    res["test_case_id"]: res["result"]
                 })
+
             try:
                 self.signal_director.signal(name, params)
             except KeyboardInterrupt:
                 raise KeyboardInterrupt
             # force output in case there was none but minimal content to increase speed.
-            test_connection.sendline('#')
-            return True
+            test_connection.sendline("#")
+            ret_val = True
 
-        elif event == 'test_case':
+        elif event == "test_case":
             match = test_connection.match
             if match is pexpect.TIMEOUT:
                 # if target.is_booted():
                 #    target.reset_boot()
-                self.logger.warning('err: lava_test_shell has timed out (test_case)')
+                self.logger.warning("err: lava_test_shell has timed out (test_case)")
             else:
                 res = self.match.match(match.groupdict())  # FIXME: rename!
-                self.logger.debug('result: %s' % res)
-                self.data['test'][self.signal_director.test_uuid].setdefault('results', {})
-                self.data['test'][self.signal_director.test_uuid]['results'].update({
-                    {res['test_case_id']: res}
+                self.logger.debug("result: %s" % res)
+                self.data["test"][self.signal_director.test_uuid].setdefault("results", {})
+                self.data["test"][self.signal_director.test_uuid]["results"].update({
+                    {res["test_case_id"]: res}
                 })
-                return True
+                ret_val = True
 
-        return False
+        return ret_val
 
     def _keep_running(self, test_connection, timeout):
         self.logger.debug("test shell timeout: %d seconds" % timeout)
@@ -229,7 +229,7 @@ class TestShellAction(TestAction):
             self._cur_handler = BaseSignalHandler(protocol)
             self.protocol = protocol  # communicate externally over the protocol API
             self.connection = None  # communicate with the device
-            self.logger = logging.getLogger('dispatcher')
+            self.logger = logging.getLogger("dispatcher")
             self.test_uuid = None
 
         def setup(self, parameters):
@@ -239,7 +239,7 @@ class TestShellAction(TestAction):
             pass
 
         def signal(self, name, params):
-            handler = getattr(self, '_on_' + name.lower(), None)
+            handler = getattr(self, "_on_" + name.lower(), None)
             if not handler and self._cur_handler:
                 handler = self._cur_handler.custom_signal
                 params = [name] + list(params)
